@@ -1,7 +1,10 @@
 package Template::Plugin::MultiMarkdown;
 
+use warnings;
 use strict;
 
+our $VERSION = 0.07;
+
 use vars qw($text_mmd_class);
 use parent qw (Template::Plugin::Filter);
 use Carp;
@@ -10,16 +13,14 @@ BEGIN {
     $text_mmd_class = 'Text::MultiMarkdown::XS';
     eval 'require Text::MultiMarkdown::XS';
     if ($@) {
-	$text_mmd_class = 'Text::MultiMarkdown';
-	eval 'require Text::MultiMarkdown';
-	if ($@) {
-	    croak "cannot load either Text::MultiMarkdown::XS or Text::MultiMarkdown";
-	}
+        $text_mmd_class = 'Text::MultiMarkdown';
+        eval 'require Text::MultiMarkdown';
+        if ($@) {
+            croak "cannot load either Text::MultiMarkdown::XS or Text::MultiMarkdown";
+        }
     }
 }
     
-our $VERSION = 0.06;
-
 sub init {
     my $self = shift;
     $self->{_DYNAMIC} = 1;
@@ -34,15 +35,13 @@ sub filter {
     my $req_class = delete $options->{implementation} || '';
 
     if ($req_class eq 'PP') {
-	require Text::MultiMarkdown;
-	return Text::MultiMarkdown->new(%$options)->markdown($text);
-    }
-    elsif ($req_class eq 'XS') {
-	require Text::MultiMarkdown::XS;
-	return Text::MultiMarkdown::XS->new($options)->markdown($text);
-    }
-    else {
-	return $text_mmd_class->new(%$options)->markdown($text);
+        require Text::MultiMarkdown;
+        return Text::MultiMarkdown->new(%$options)->markdown($text);
+    } elsif ($req_class eq 'XS') {
+        require Text::MultiMarkdown::XS;
+        return Text::MultiMarkdown::XS->new($options)->markdown($text);
+    } else {
+    	return $text_mmd_class->new(%$options)->markdown($text);
     }
 }
 
@@ -95,26 +94,47 @@ There are two methods required by the TT plugin API:
 
 =back
 
-=head1 VERSION
-
-This man page describes version 0.04.
-
 =head1 SEE ALSO
 
 L<Template>, L<Text::MultiMarkdown>, L<http://fletcherpenney.net/multimarkdown/>
 
+=head1 DEDICATION
+
+This distribution was originally created by Andrew Ford. Sadly in early 2014,
+Andrew was diagnosed with Pancreatic Cancer and passed away peacfully at home
+on 25th April 2014.
+
+One of his wishes was for his OpenSource work to continue. At his funeral, many
+of his colleagues and friends, spoke of how he felt like a person of the world, 
+and how he embrace the idea of OpenSource being for the benefit of the world.
+
+Anyone wishing to donate in memory of Andrew, please consider the following
+charities:
+
+=over
+
+=item Dignity in Dying - L<http://www.dignityindying.org.uk/>
+
+=item Marie Curie Cancer Care - L<http://www.mariecurie.org.uk/>
+
+=back
+
 =head1 AUTHOR
 
-Andrew Ford E<lt>A.Ford@ford-mason.co.ukE<gt> (based on the
-L<Template::Plugin::Markdown> TT plugin by Naoya Ito
-E<lt>naoya@bloghackers.netE<gt>).
+  Original Author:    Andrew Ford               2006-2014
+  Current Maintainer: Barbie <barbie@cpan.org>  2014
 
-=head1 LICENSE AND COPYRIGHT
+=head1 ACKNOWLEDGEMENTS
 
-Copyright (C) 2009 Andrew Ford
+Andrew Ford based this module on the L<Template::Plugin::Markdown> TT plugin
+by Naoya Ito E<lt>naoya@bloghackers.netE<gt>.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT & LICENSE
+
+Copyright (C) 2008-2014 Andrew Ford
+Copyright (C) 2014      Barbie for Miss Barbell Productions.
+
+This distribution is free software; you can redistribute it and/or
+modify it under the Artistic Licence v2.
 
 =cut
-
